@@ -34,3 +34,10 @@ test_that("format() works for wksxp", {
   )
   expect_identical(wksxp_format(list(NULL)), NA_character_)
 })
+
+test_that("format() handles errors", {
+  bad_wkb <- wkt_translate_wkb("POINT (30 10)", endian = 1)
+  bad_wkb[[1]][2] <- as.raw(0xff)
+  expect_match(wkb_format(bad_wkb), "!!!")
+  expect_match(wkt_format("POINT ENTPY"), "!!!")
+})
